\name{biomarker.power.table}
\alias{biomarker.power.table}
\title{Power tables for the tail-rank test}
\description{
  Compute an array of power tables for the tail-rank.test.
}
\usage{
biomarker.power.table(G)
biomarker.power.table(G, N = seq(25, 250, by = 25))
biomarker.power.table(G, psi = c(0.95, 0.99))
biomarker.power.table(G, conf = 0.99)
biomarker.power.table(G, phi = seq(0.1, 0.5, by = 0.05))
biomarker.power.table(G, N, psi, conf, phi)
}
\arguments{
  \item{G}{An integer; the number of genes being assessed as potential
    biomarkers. Statistically, the number of hypotheses being tested.}
  \item{N}{An integer; the number of "test" or "cancer" samples used.}
  \item{psi}{A real number between 0 and 1; the desired specificity of
    the test.}
  \item{conf}{A real number between 0 and 1; the confidence level of the
    results. Can be obtained by subtracting the family-wise Type I error
    from 1.}
  \item{phi}{A real number between 0 and 1; the sensitivity that one
    would like to be able to detect, conditional on the specificity.}
}
\value{
  Returns a list of objects of the \code{\link{bmpt}} class. Each item
  in the list consists of a two-dimensional table (indexed by the sample
  sizes \code{N} and the sensitivities \code{phi}) with scalars
  recording the values of \code{G}, \code{conf}, and \code{psi} that
  were used to generate it.
}

\note{Default values of the optional arguments (\code{N}, \code{psi},
  \code{conf}, \code{phi})are included in the usage examples.
}
\author{Kevin R. Coombes <kcoombes@mdanderson.org>}
\seealso{\code{\link{tail.rank.test}},
  \code{\link{tail.rank.power}},
  \code{\link{biomarker.power.table}},
  \code{\link{matrix.mean}},
  \code{\link{tol.bound}}
}
\examples{
stuff <- biomarker.power.table(10000,
                               c(10, 20, 50, 100, 250, 500),
                               c(0.95, 0.99),
                               c(0.99, 0.95),
                               seq(0.1, 0.7, by=0.1))
lapply(stuff, summary)
}
\keyword{univar}
\keyword{multivariate}
\keyword{htest}
\keyword{nonparametric}
