\name{tail.rank.test-methods}
\docType{methods}
\alias{getStatistic,tail.rank.test-method}
\alias{summary,tail.rank.test-method}
\alias{hist,tail.rank.test-method}
\alias{as.logical,tail.rank.test-method}

\title{Methods for tail.rank.test objects}
\description{
  This file describes the methods for an object of the class
  \code{\link[tail.rank.test-class]{tail.rank.test}} class.
}
\usage{
\S4method{summary}{tail.rank.test}(object, ...)
\S4method{hist}{tail.rank.test}(x, overlay, ...)
\S4method{as.logical}{tail.rank.test}(x, ...)
\S4method{getStatistic}{tail.rank.test}(object,...)
}
\arguments{
  \item{x}{A \code{\link[tail.rank.test-class]{tail.rank.test} object}}
  \item{object}{A \code{\link[tail.rank.test-class]{tail.rank.test} object}}
  \item{overlay}{An optional logical flag; defaults to \code{FALSE}.}
  \item{\dots}{Extra graphical parameters}
}
\value{
  \item{\code{as.logical}}{Returns a logical vector. \code{TRUE} values
    pick out candidate biomarkers where the tail-rank test statistic
    exceeds the significance cutoff.}
  \item{\code{getStatistic}}{Returns the vector of tail-rank statistics
    contained in \code{object}.}
  \item{\code{hist}}{Invisibly returns the tail.rank.test object.}
  \item{\code{summary}}{Invisibly returns the tail.rank.test object.}
}
\author{Kevin R. Coombes <kcoombes@mdanderson.org>}
\seealso{\code{\link{tail.rank.test-class}},
  \code{\link{tail.rank.test}},
  \code{\link{tail.rank.power}}
}
\examples{
# generate some fake data to use in the example
nr <- 40000
nc <- 110
fake.data <- matrix(rnorm(nr*nc), ncol=nc)
fake.class <- rep(c(TRUE, FALSE), c(40, 70))

# build an object
null.tr <-  tail.rank.test(fake.data, fake.class)

# summarize the object
summary(null.tr)

# plot a histogram
hist(null.tr)
hist(null.tr, breaks=70, col='blue', overlay=TRUE)

# get a logical vector that can select those markers
# identified by the test
selector <- as.logical(null.tr)
}
\keyword{manip}
